.. _pyutils:

Python utilities
****************

.. currentmodule:: datalad_next
.. autosummary::
   :toctree: generated

   commands.ValidatedInterface
   config.ConfigManager
   constraints
   credman.manager
   datasets
   exceptions
   iter_collections
   url_operations
   url_operations.any
   url_operations.file
   url_operations.http
   url_operations.ssh
   utils
   utils.http_helpers
   utils.multihash
   utils.requests_auth
   tests.fixtures
   types.annexkey
   types.archivist
   types.enums
